Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(122)

Unified Diff: src/core/SkMatrix.cpp

Issue 1316233002: Style Change: NULL->nullptr (Closed) Base URL: https://skia.googlesource.com/skia.git@master
Patch Set: 2015-08-27 (Thursday) 10:25:06 EDT Created 5 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « src/core/SkMaskGamma.h ('k') | src/core/SkMatrixImageFilter.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/core/SkMatrix.cpp
diff --git a/src/core/SkMatrix.cpp b/src/core/SkMatrix.cpp
index f5e4e803f2931b1219edab3611ecc72a382dadac..13a9ac28f0a715e59cdf3138aef84f3321944353 100644
--- a/src/core/SkMatrix.cpp
+++ b/src/core/SkMatrix.cpp
@@ -858,7 +858,7 @@ bool SkMatrix::invertNonIdentity(SkMatrix* inv) const {
// translate only
inv->setTranslate(-fMat[kMTransX], -fMat[kMTransY]);
}
- } else { // inv is NULL, just check if we're invertible
+ } else { // inv is nullptr, just check if we're invertible
if (!fMat[kMScaleX] || !fMat[kMScaleY]) {
invertible = false;
}
@@ -878,7 +878,7 @@ bool SkMatrix::invertNonIdentity(SkMatrix* inv) const {
SkMatrix* tmp = inv;
SkMatrix storage;
- if (applyingInPlace || NULL == tmp) {
+ if (applyingInPlace || nullptr == tmp) {
tmp = &storage; // we either need to avoid trampling memory or have no memory
}
« no previous file with comments | « src/core/SkMaskGamma.h ('k') | src/core/SkMatrixImageFilter.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698